@@ -81,8 +81,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x06f0 & 0xFF, 0x06f9 & 0xFF},
 	{0x06fa & 0xFF, 0x06fc & 0xFF},
 	{0x06ff & 0xFF, 0x06ff & 0xFF},
-	{0x070f & 0xFF, 0x070f & 0xFF},
-	{0x0710 & 0xFF, 0x0710 & 0xFF},
+	{0x070f & 0xFF, 0x0710 & 0xFF},
 	{0x0711 & 0xFF, 0x0711 & 0xFF},
 	{0x0712 & 0xFF, 0x072f & 0xFF},
 	{0x0730 & 0xFF, 0x074a & 0xFF},
@@ -107,9 +106,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0840 & 0xFF, 0x0858 & 0xFF},
 	{0x0859 & 0xFF, 0x085b & 0xFF},
 	{0x0860 & 0xFF, 0x086a & 0xFF},
-	{0x08a0 & 0xFF, 0x08b4 & 0xFF},
-	{0x08b6 & 0xFF, 0x08c7 & 0xFF},
-	{0x08d3 & 0xFF, 0x08e1 & 0xFF},
+	{0x0870 & 0xFF, 0x0887 & 0xFF},
+	{0x0889 & 0xFF, 0x088e & 0xFF},
+	{0x0890 & 0xFF, 0x0891 & 0xFF},
+	{0x0898 & 0xFF, 0x089f & 0xFF},
+	{0x08a0 & 0xFF, 0x08c9 & 0xFF},
+	{0x08ca & 0xFF, 0x08e1 & 0xFF},
 	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
 	{0x08e3 & 0xFF, 0x08ff & 0xFF},
 	{0x0900 & 0xFF, 0x0903 & 0xFF},
@@ -221,12 +223,14 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0c0e & 0xFF, 0x0c10 & 0xFF},
 	{0x0c12 & 0xFF, 0x0c28 & 0xFF},
 	{0x0c2a & 0xFF, 0x0c39 & 0xFF},
+	{0x0c3c & 0xFF, 0x0c3c & 0xFF},
 	{0x0c3d & 0xFF, 0x0c3d & 0xFF},
 	{0x0c3e & 0xFF, 0x0c44 & 0xFF},
 	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
 	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
 	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
 	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
+	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
 	{0x0c60 & 0xFF, 0x0c61 & 0xFF},
 	{0x0c62 & 0xFF, 0x0c63 & 0xFF},
 	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
@@ -243,11 +247,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
 	{0x0cca & 0xFF, 0x0ccd & 0xFF},
 	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
-	{0x0cde & 0xFF, 0x0cde & 0xFF},
+	{0x0cdd & 0xFF, 0x0cde & 0xFF},
 	{0x0ce0 & 0xFF, 0x0ce1 & 0xFF},
 	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
 	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
 	{0x0cf1 & 0xFF, 0x0cf2 & 0xFF},
+	{0x0cf3 & 0xFF, 0x0cf3 & 0xFF},
 	{0x0d00 & 0xFF, 0x0d03 & 0xFF},
 	{0x0d04 & 0xFF, 0x0d0c & 0xFF},
 	{0x0d0e & 0xFF, 0x0d10 & 0xFF},
@@ -282,7 +287,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x0e50 & 0xFF, 0x0e59 & 0xFF},
 	{0x0eb1 & 0xFF, 0x0eb1 & 0xFF},
 	{0x0eb4 & 0xFF, 0x0ebc & 0xFF},
-	{0x0ec8 & 0xFF, 0x0ecd & 0xFF},
+	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
 	{0x0ed0 & 0xFF, 0x0ed9 & 0xFF},
 	{0x0f00 & 0xFF, 0x0f00 & 0xFF},
 	{0x0f18 & 0xFF, 0x0f19 & 0xFF},
@@ -345,10 +350,9 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1681 & 0xFF, 0x169a & 0xFF},
 	{0x16a0 & 0xFF, 0x16ea & 0xFF},
 	{0x16ee & 0xFF, 0x16f8 & 0xFF},
-	{0x1700 & 0xFF, 0x170c & 0xFF},
-	{0x170e & 0xFF, 0x1711 & 0xFF},
-	{0x1712 & 0xFF, 0x1714 & 0xFF},
-	{0x1720 & 0xFF, 0x1731 & 0xFF},
+	{0x1700 & 0xFF, 0x1711 & 0xFF},
+	{0x1712 & 0xFF, 0x1715 & 0xFF},
+	{0x171f & 0xFF, 0x1731 & 0xFF},
 	{0x1732 & 0xFF, 0x1734 & 0xFF},
 	{0x1740 & 0xFF, 0x1751 & 0xFF},
 	{0x1752 & 0xFF, 0x1753 & 0xFF},
@@ -360,6 +364,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x17e0 & 0xFF, 0x17e9 & 0xFF},
 	{0x180b & 0xFF, 0x180d & 0xFF},
 	{0x180e & 0xFF, 0x180e & 0xFF},
+	{0x180f & 0xFF, 0x180f & 0xFF},
 	{0x1810 & 0xFF, 0x1819 & 0xFF},
 	{0x1820 & 0xFF, 0x1878 & 0xFF},
 	{0x1880 & 0xFF, 0x1884 & 0xFF},
@@ -380,11 +385,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
 	{0x1a80 & 0xFF, 0x1a89 & 0xFF},
 	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
-	{0x1ab0 & 0xFF, 0x1ac0 & 0xFF},
+	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
 	{0x1b00 & 0xFF, 0x1b04 & 0xFF},
 	{0x1b05 & 0xFF, 0x1b33 & 0xFF},
 	{0x1b34 & 0xFF, 0x1b44 & 0xFF},
-	{0x1b45 & 0xFF, 0x1b4b & 0xFF},
+	{0x1b45 & 0xFF, 0x1b4c & 0xFF},
 	{0x1b50 & 0xFF, 0x1b59 & 0xFF},
 	{0x1b6b & 0xFF, 0x1b73 & 0xFF},
 	{0x1b80 & 0xFF, 0x1b82 & 0xFF},
@@ -413,8 +418,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1cf7 & 0xFF, 0x1cf9 & 0xFF},
 	{0x1cfa & 0xFF, 0x1cfa & 0xFF},
 	{0x1d00 & 0xFF, 0x1dbf & 0xFF},
-	{0x1dc0 & 0xFF, 0x1df9 & 0xFF},
-	{0x1dfb & 0xFF, 0x1dff & 0xFF},
+	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
 	{0x1e00 & 0xFF, 0x1eff & 0xFF},
 	{0x1f00 & 0xFF, 0x1f15 & 0xFF},
 	{0x1f18 & 0xFF, 0x1f1d & 0xFF},
@@ -471,9 +475,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x214e & 0xFF, 0x214e & 0xFF},
 	{0x2160 & 0xFF, 0x2188 & 0xFF},
 	{0x24b6 & 0xFF, 0x24e9 & 0xFF},
-	{0x2c00 & 0xFF, 0x2c2e & 0xFF},
-	{0x2c30 & 0xFF, 0x2c5e & 0xFF},
-	{0x2c60 & 0xFF, 0x2ce4 & 0xFF},
+	{0x2c00 & 0xFF, 0x2ce4 & 0xFF},
 	{0x2ceb & 0xFF, 0x2cee & 0xFF},
 	{0x2cef & 0xFF, 0x2cf1 & 0xFF},
 	{0x2cf2 & 0xFF, 0x2cf3 & 0xFF},
@@ -527,9 +529,11 @@ static const uint8_t unicode_rangetab[][2]={
 	{0xa69e & 0xFF, 0xa69f & 0xFF},
 	{0xa6a0 & 0xFF, 0xa6ef & 0xFF},
 	{0xa6f0 & 0xFF, 0xa6f1 & 0xFF},
-	{0xa708 & 0xFF, 0xa7bf & 0xFF},
-	{0xa7c2 & 0xFF, 0xa7ca & 0xFF},
-	{0xa7f5 & 0xFF, 0xa7ff & 0xFF},
+	{0xa708 & 0xFF, 0xa7ca & 0xFF},
+	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
+	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
+	{0xa7d5 & 0xFF, 0xa7d9 & 0xFF},
+	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
 	{0xa800 & 0xFF, 0xa801 & 0xFF},
 	{0xa802 & 0xFF, 0xa802 & 0xFF},
 	{0xa803 & 0xFF, 0xa805 & 0xFF},
@@ -710,10 +714,21 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x104d8 & 0xFF, 0x104fb & 0xFF},
 	{0x10500 & 0xFF, 0x10527 & 0xFF},
 	{0x10530 & 0xFF, 0x10563 & 0xFF},
+	{0x10570 & 0xFF, 0x1057a & 0xFF},
+	{0x1057c & 0xFF, 0x1058a & 0xFF},
+	{0x1058c & 0xFF, 0x10592 & 0xFF},
+	{0x10594 & 0xFF, 0x10595 & 0xFF},
+	{0x10597 & 0xFF, 0x105a1 & 0xFF},
+	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
+	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
+	{0x105bb & 0xFF, 0x105bc & 0xFF},
 	{0x10600 & 0xFF, 0x106ff & 0xFF},
 	{0x10700 & 0xFF, 0x10736 & 0xFF},
 	{0x10740 & 0xFF, 0x10755 & 0xFF},
 	{0x10760 & 0xFF, 0x10767 & 0xFF},
+	{0x10780 & 0xFF, 0x10785 & 0xFF},
+	{0x10787 & 0xFF, 0x107b0 & 0xFF},
+	{0x107b2 & 0xFF, 0x107ba & 0xFF},
 	{0x10800 & 0xFF, 0x10805 & 0xFF},
 	{0x10808 & 0xFF, 0x10808 & 0xFF},
 	{0x1080a & 0xFF, 0x10835 & 0xFF},
@@ -755,20 +770,28 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
 	{0x10eab & 0xFF, 0x10eac & 0xFF},
 	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
+	{0x10efd & 0xFF, 0x10eff & 0xFF},
 	{0x10f00 & 0xFF, 0x10f1c & 0xFF},
 	{0x10f27 & 0xFF, 0x10f27 & 0xFF},
 	{0x10f30 & 0xFF, 0x10f45 & 0xFF},
 	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
+	{0x10f70 & 0xFF, 0x10f81 & 0xFF},
+	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
 	{0x10fb0 & 0xFF, 0x10fc4 & 0xFF},
 	{0x10fe0 & 0xFF, 0x10ff6 & 0xFF},
 	{0x11000 & 0xFF, 0x11002 & 0xFF},
 	{0x11003 & 0xFF, 0x11037 & 0xFF},
 	{0x11038 & 0xFF, 0x11046 & 0xFF},
 	{0x11066 & 0xFF, 0x1106f & 0xFF},
+	{0x11070 & 0xFF, 0x11070 & 0xFF},
+	{0x11071 & 0xFF, 0x11072 & 0xFF},
+	{0x11073 & 0xFF, 0x11074 & 0xFF},
+	{0x11075 & 0xFF, 0x11075 & 0xFF},
 	{0x1107f & 0xFF, 0x11082 & 0xFF},
 	{0x11083 & 0xFF, 0x110af & 0xFF},
 	{0x110b0 & 0xFF, 0x110ba & 0xFF},
 	{0x110bd & 0xFF, 0x110bd & 0xFF},
+	{0x110c2 & 0xFF, 0x110c2 & 0xFF},
 	{0x110cd & 0xFF, 0x110cd & 0xFF},
 	{0x110d0 & 0xFF, 0x110e8 & 0xFF},
 	{0x110f0 & 0xFF, 0x110f9 & 0xFF},
@@ -795,6 +818,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11213 & 0xFF, 0x1122b & 0xFF},
 	{0x1122c & 0xFF, 0x11237 & 0xFF},
 	{0x1123e & 0xFF, 0x1123e & 0xFF},
+	{0x1123f & 0xFF, 0x11240 & 0xFF},
+	{0x11241 & 0xFF, 0x11241 & 0xFF},
 	{0x11280 & 0xFF, 0x11286 & 0xFF},
 	{0x11288 & 0xFF, 0x11288 & 0xFF},
 	{0x1128a & 0xFF, 0x1128d & 0xFF},
@@ -884,7 +909,7 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11a5c & 0xFF, 0x11a89 & 0xFF},
 	{0x11a8a & 0xFF, 0x11a99 & 0xFF},
 	{0x11a9d & 0xFF, 0x11a9d & 0xFF},
-	{0x11ac0 & 0xFF, 0x11af8 & 0xFF},
+	{0x11ab0 & 0xFF, 0x11af8 & 0xFF},
 	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
 	{0x11c0a & 0xFF, 0x11c2e & 0xFF},
 	{0x11c2f & 0xFF, 0x11c36 & 0xFF},
@@ -914,6 +939,14 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
 	{0x11ee0 & 0xFF, 0x11ef2 & 0xFF},
 	{0x11ef3 & 0xFF, 0x11ef6 & 0xFF},
+	{0x11f00 & 0xFF, 0x11f01 & 0xFF},
+	{0x11f02 & 0xFF, 0x11f02 & 0xFF},
+	{0x11f03 & 0xFF, 0x11f03 & 0xFF},
+	{0x11f04 & 0xFF, 0x11f10 & 0xFF},
+	{0x11f12 & 0xFF, 0x11f33 & 0xFF},
+	{0x11f34 & 0xFF, 0x11f3a & 0xFF},
+	{0x11f3e & 0xFF, 0x11f42 & 0xFF},
+	{0x11f50 & 0xFF, 0x11f59 & 0xFF},
 	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
 	{0x12000 & 0xFF, 0x120ff & 0xFF},
 	{0x12100 & 0xFF, 0x121ff & 0xFF},
@@ -922,12 +955,16 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x12400 & 0xFF, 0x1246e & 0xFF},
 	{0x12480 & 0xFF, 0x124ff & 0xFF},
 	{0x12500 & 0xFF, 0x12543 & 0xFF},
+	{0x12f90 & 0xFF, 0x12ff0 & 0xFF},
 	{0x13000 & 0xFF, 0x130ff & 0xFF},
 	{0x13100 & 0xFF, 0x131ff & 0xFF},
 	{0x13200 & 0xFF, 0x132ff & 0xFF},
 	{0x13300 & 0xFF, 0x133ff & 0xFF},
-	{0x13400 & 0xFF, 0x1342e & 0xFF},
-	{0x13430 & 0xFF, 0x13438 & 0xFF},
+	{0x13400 & 0xFF, 0x1342f & 0xFF},
+	{0x13430 & 0xFF, 0x1343f & 0xFF},
+	{0x13440 & 0xFF, 0x13440 & 0xFF},
+	{0x13441 & 0xFF, 0x13446 & 0xFF},
+	{0x13447 & 0xFF, 0x13455 & 0xFF},
 	{0x14400 & 0xFF, 0x144ff & 0xFF},
 	{0x14500 & 0xFF, 0x145ff & 0xFF},
 	{0x14600 & 0xFF, 0x14646 & 0xFF},
@@ -936,6 +973,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16a00 & 0xFF, 0x16a38 & 0xFF},
 	{0x16a40 & 0xFF, 0x16a5e & 0xFF},
 	{0x16a60 & 0xFF, 0x16a69 & 0xFF},
+	{0x16a70 & 0xFF, 0x16abe & 0xFF},
+	{0x16ac0 & 0xFF, 0x16ac9 & 0xFF},
 	{0x16ad0 & 0xFF, 0x16aed & 0xFF},
 	{0x16af0 & 0xFF, 0x16af4 & 0xFF},
 	{0x16b00 & 0xFF, 0x16b2f & 0xFF},
@@ -955,7 +994,12 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x16fe3 & 0xFF, 0x16fe3 & 0xFF},
 	{0x16fe4 & 0xFF, 0x16fe4 & 0xFF},
 	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
+	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
+	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
+	{0x1affd & 0xFF, 0x1affe & 0xFF},
 	{0x1b000 & 0xFF, 0x1b000 & 0xFF},
+	{0x1b120 & 0xFF, 0x1b122 & 0xFF},
+	{0x1b155 & 0xFF, 0x1b155 & 0xFF},
 	{0x1b164 & 0xFF, 0x1b167 & 0xFF},
 	{0x1bc00 & 0xFF, 0x1bc6a & 0xFF},
 	{0x1bc70 & 0xFF, 0x1bc7c & 0xFF},
@@ -963,6 +1007,8 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
 	{0x1bc9d & 0xFF, 0x1bc9e & 0xFF},
 	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
+	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
+	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
 	{0x1d165 & 0xFF, 0x1d169 & 0xFF},
 	{0x1d16d & 0xFF, 0x1d172 & 0xFF},
 	{0x1d173 & 0xFF, 0x1d17a & 0xFF},
@@ -1010,19 +1056,32 @@ static const uint8_t unicode_rangetab[][2]={
 	{0x1da84 & 0xFF, 0x1da84 & 0xFF},
 	{0x1da9b & 0xFF, 0x1da9f & 0xFF},
 	{0x1daa1 & 0xFF, 0x1daaf & 0xFF},
+	{0x1df00 & 0xFF, 0x1df1e & 0xFF},
+	{0x1df25 & 0xFF, 0x1df2a & 0xFF},
 	{0x1e000 & 0xFF, 0x1e006 & 0xFF},
 	{0x1e008 & 0xFF, 0x1e018 & 0xFF},
 	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
 	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
 	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
+	{0x1e030 & 0xFF, 0x1e06d & 0xFF},
+	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
 	{0x1e100 & 0xFF, 0x1e12c & 0xFF},
 	{0x1e130 & 0xFF, 0x1e136 & 0xFF},
 	{0x1e137 & 0xFF, 0x1e13d & 0xFF},
 	{0x1e140 & 0xFF, 0x1e149 & 0xFF},
 	{0x1e14e & 0xFF, 0x1e14e & 0xFF},
+	{0x1e290 & 0xFF, 0x1e2ad & 0xFF},
+	{0x1e2ae & 0xFF, 0x1e2ae & 0xFF},
 	{0x1e2c0 & 0xFF, 0x1e2eb & 0xFF},
 	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
 	{0x1e2f0 & 0xFF, 0x1e2f9 & 0xFF},
+	{0x1e4d0 & 0xFF, 0x1e4eb & 0xFF},
+	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
+	{0x1e4f0 & 0xFF, 0x1e4f9 & 0xFF},
+	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
+	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
+	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
+	{0x1e7f0 & 0xFF, 0x1e7fe & 0xFF},
 	{0x1e800 & 0xFF, 0x1e8c4 & 0xFF},
 	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
 	{0x1e900 & 0xFF, 0x1e943 & 0xFF},
@@ -1132,7 +1191,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Hebrew_Letter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_MidLetter,
-	UNICODE_WB_Format,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_MidNum,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Format,
@@ -1146,7 +1205,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
-	UNICODE_WB_Format,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -1155,7 +1214,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
-	UNICODE_WB_Format,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -1183,8 +1241,11 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
-	UNICODE_WB_Format,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -1295,6 +1356,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -1302,6 +1364,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
@@ -1323,6 +1386,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1420,7 +1484,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -1434,6 +1497,7 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Format,
+	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1488,7 +1552,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
-	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1547,8 +1610,6 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
-	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1605,6 +1666,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -1803,6 +1866,17 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -1829,11 +1903,14 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -1842,8 +1919,13 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
-	UNICODE_WB_Format,
-	UNICODE_WB_Format,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_Extend,
@@ -1870,6 +1952,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -1988,6 +2072,15 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2002,6 +2095,9 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Format,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2011,6 +2107,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
@@ -2031,6 +2129,11 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Katakana,
 	UNICODE_WB_Katakana,
+	UNICODE_WB_Katakana,
+	UNICODE_WB_Katakana,
+	UNICODE_WB_Katakana,
+	UNICODE_WB_Katakana,
+	UNICODE_WB_Katakana,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
@@ -2039,6 +2142,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Format,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
+	UNICODE_WB_Extend,
 	UNICODE_WB_Format,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -2084,6 +2189,8 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
 	UNICODE_WB_Extend,
@@ -2092,13 +2199,24 @@ static const uint8_t unicode_classtab[]={
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_Numeric,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
+	UNICODE_WB_Numeric,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_ALetter,
+	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
 	UNICODE_WB_Extend,
 	UNICODE_WB_ALetter,
@@ -2287,6 +2405,7 @@ static const size_t unicode_starting_indextab[]={
 	291,
 	292,
 	293,
+	303,
 	304,
 	305,
 	306,
@@ -2301,9 +2420,11 @@ static const size_t unicode_starting_indextab[]={
 	363,
 	366,
 	367,
+	431,
 	432,
 	433,
 	444,
+	463,
 	465,
 	466,
 	468,
@@ -2311,9 +2432,12 @@ static const size_t unicode_starting_indextab[]={
 	470,
 	471,
 	474,
+	479,
 	480,
 	481,
 	482,
+	484,
+	487,
 	488,
 	489,
 	494,
@@ -2333,56 +2457,52 @@ static const char32_t unicode_starting_pagetab[]={
 	42,
 	59,
 	82,
-	97,
-	113,
-	145,
-	182,
-	217,
-	249,
-	277,
-	285,
-	300,
-	316,
-	317,
-	331,
-	338,
-	339,
-	340,
-	346,
-	359,
-	369,
+	96,
+	115,
+	147,
+	184,
+	219,
+	254,
+	282,
+	290,
+	305,
+	321,
+	322,
+	336,
+	343,
+	344,
+	345,
+	351,
+	363,
 	374,
-	382,
-	395,
-	413,
-	416,
-	417,
-	436,
-	457,
-	471,
-	472,
-	478,
-	494,
-	495,
-	504,
-	508,
-	509,
+	379,
+	387,
+	400,
+	418,
+	420,
+	421,
+	440,
+	461,
+	475,
+	476,
+	480,
+	496,
+	497,
+	506,
 	510,
 	511,
 	512,
 	513,
 	514,
+	515,
 	516,
-	517,
-	528,
-	531,
-	550,
-	563,
-	580,
-	590,
-	591,
-	592,
-	593,
+	518,
+	519,
+	530,
+	535,
+	554,
+	567,
+	584,
 	594,
 	595,
 	596,
@@ -2423,82 +2543,92 @@ static const char32_t unicode_starting_pagetab[]={
 	631,
 	632,
 	633,
+	634,
+	635,
 	636,
-	649,
-	650,
+	637,
+	640,
+	653,
 	654,
-	668,
-	685,
-	692,
-	694,
-	697,
-	705,
+	658,
+	672,
+	689,
+	696,
+	698,
+	701,
 	709,
-	711,
-	712,
-	715,
-	725,
-	729,
-	743,
-	747,
-	750,
-	753,
-	756,
+	713,
+	723,
+	724,
+	730,
+	740,
+	744,
+	758,
 	762,
-	773,
-	792,
-	804,
-	822,
-	833,
-	838,
-	846,
-	848,
-	853,
+	765,
+	768,
+	772,
+	780,
+	796,
+	815,
+	829,
+	847,
+	858,
+	863,
+	871,
 	873,
-	886,
-	895,
-	913,
-	915,
-	916,
-	917,
-	918,
-	919,
+	878,
+	898,
+	911,
 	920,
-	922,
-	923,
-	924,
-	925,
-	926,
-	927,
-	929,
-	930,
-	931,
-	932,
-	933,
-	934,
-	939,
-	945,
-	946,
+	938,
+	940,
+	949,
+	950,
+	951,
+	952,
+	953,
+	955,
 	956,
 	957,
 	958,
-	964,
+	959,
+	960,
+	961,
+	966,
+	967,
+	968,
+	969,
 	970,
 	971,
-	981,
-	991,
-	996,
-	1005,
-	1011,
+	978,
+	984,
+	985,
+	995,
+	998,
+	999,
+	1002,
+	1008,
+	1010,
 	1016,
-	1021,
-	1024,
-	1026,
-	1030,
-	1063,
-	1067,
-	1068,
-	1069,
-	1071
+	1017,
+	1027,
+	1037,
+	1042,
+	1051,
+	1057,
+	1059,
+	1066,
+	1071,
+	1076,
+	1079,
+	1083,
+	1085,
+	1089,
+	1122,
+	1126,
+	1127,
+	1128,
+	1130
 };
 
